preqc-lr
====================================
preqc-lr is a software tool that performs quality control checks to long read sequencing data.

Install
====================================
To install from source:

```bash
git clone https://github.com/simpsonlab/preqc-lr.git
cd preqc-lr
python setup.py install
```

What is preqc-lr?
====================================
With the emergence of new long read sequencing technology such as Pacbio Single Molecule, Real-Time (SMRT) S
equencing technology and Oxford Nanopore Technologies (ONT), there is a need for a method that assesses sequ
encing quality prior to analyses. With preqc-lr we enable users to visualize metrics of quality.

There are two components to preqc-lr:

    1. calculate
    2. report
